
# q-expansion of newform 1344.2.bb.g, downloaded from the LMFDB on 03 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1344
weight = 2
poly_data = [576, 0, 2592, 0, 3780, 0, 2040, 0, 432, 0, 36, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, -9360, 0, -9564, 0, -5112, 0, -1176, 0, -104, 0, -3], 4032], [[76176, -9360, 199476, -9564, 126648, -5112, 28560, -1176, 2448, -104, 69, -3], 8064], [[-44160, 26928, -115200, 43356, -74208, 23448, -16688, 4872, -1424, 400, -40, 11], 2688], [[-384, 9936, 0, 25956, 0, 16632, 0, 3744, 0, 320, 0, 9], 768], [[39888, -72432, 101700, -164772, 69864, -98496, 16464, -21588, 1440, -1824, 41, -51], 4032], [[93312, -110160, 202752, -274500, 110016, -181176, 22176, -41496, 1776, -3576, 48, -101], 8064], [[-132480, 139536, -345600, 418932, -222624, 292008, -50064, 68376, -4272, 5952, -120, 169], 8064], [[-22032, 91152, -28692, 236988, -15336, 153912, -3528, 35028, -312, 3012, -9, 85], 4032], [[0, 110160, 0, 274500, 0, 181176, 0, 41496, 0, 3576, 0, 101], 4032], [[-39888, 109872, -101700, 309204, -69864, 209328, -16464, 48468, -1440, 4200, -41, 119], 4032], [[0, -91152, 0, -236988, 0, -153912, 0, -35028, 0, -3012, 0, -85], 2016]]

hecke_ring_character_values = [[127, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1093, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [449, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [577, [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 1, 0, 0, -1, 0, 0, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1], [1, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0], [0, 1, -1, 0, 0, 1, 0, 0, 2, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, -2], [2, 0, 0, 1, 4, 0, 0, -1, 0, -1, 0, 0], [0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 1, 3], [6, 0, 0, 0, 3, 0, 1, 0, 0, 1, 0, 0], [2, 0, 0, 0, 4, 0, 0, 0, 0, 2, 0, 0], [0, -1, 2, 0, 0, 1, 0, 0, 4, 0, -1, 1], [0, 2, 2, 0, 0, 2, 0, 0, 2, 0, 0, -2], [2, 0, 0, 2, -2, 0, 4, 1, 0, -1, 0, 0], [0, 0, -6, 0, 0, 2, 0, 0, 2, 0, -1, -1], [0, 0, 0, 2, 2, 0, 2, 0, 0, -2, 0, 0], [0, 6, -3, 0, 0, 0, 0, 0, 2, 0, -3, 1], [0, -6, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0], [-1, 0, 0, -4, 1, 0, -3, -2, 0, 2, 0, 0], [0, 1, -1, 0, 0, 1, 0, 0, -1, 0, -2, -3], [0, 0, 0, 0, 0, -3, 0, 0, 0, 0, -3, 1], [-8, 0, 0, 4, -4, 0, 4, 8, 0, -4, 0, 0], [2, 0, 0, -2, 4, 0, 0, 2, 0, -3, 0, 0], [-6, 0, 0, 0, -6, 0, 0, -2, 0, 2, 0, 0], [0, 1, 1, 0, 0, -3, 0, 0, 0, 0, 0, 0], [0, 2, 2, 0, 0, 3, 0, 0, 2, 0, 0, -2], [5, 0, 0, 4, -5, 0, -1, 2, 0, -2, 0, 0], [6, 0, 0, 4, 0, 0, 4, 4, 0, -2, 0, 0], [0, -5, 0, 0, 0, -3, 0, 0, 0, 0, -3, 0], [0, 0, 0, 0, 0, -1, 0, 0, 2, 0, 2, 4], [0, 0, 0, 0, 0, 0, 4, 4, 0, 4, 0, 0], [0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, -5], [8, 0, 0, 0, 4, 0, -2, 0, 0, -2, 0, 0], [0, 0, -2, 0, 0, 0, 0, 0, -1, 0, 0, 0], [-14, 0, 0, 0, -14, 0, -2, 0, 0, -4, 0, 0], [0, 2, 2, 0, 0, -4, 0, 0, -4, 0, 0, 4], [0, -2, 4, 0, 0, 2, 0, 0, 0, 0, -2, -2], [0, 0, 0, -2, 12, 0, -2, 0, 0, 2, 0, 0], [0, 20, -10, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, -6, 0, 0, -2, -6, 0, 5, 0, 0], [0, 6, -6, 0, 0, -2, 0, 0, -4, 0, 4, 0], [-1, 0, 0, 0, -1, 0, 0, -2, 0, 2, 0, 0], [4, 0, 0, -4, 8, 0, 0, 4, 0, -2, 0, 0], [0, 12, -6, 0, 0, 0, 0, 0, 2, 0, -4, 0], [0, -6, 12, 0, 0, -4, 0, 0, 0, 0, 4, 4], [0, 8, -16, 0, 0, -2, 0, 0, -2, 0, 2, 1], [0, 0, -12, 0, 0, -2, 0, 0, -4, 0, 1, 1], [0, 0, 0, -2, -1, 0, -3, 0, 0, 3, 0, 0], [0, 0, 0, 0, 18, 0, 0, 0, 0, 0, 0, 0], [0, -6, 0, 0, 0, 2, 0, 0, 0, 0, 2, -4], [-2, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0], [0, 6, 0, 0, 0, 7, 0, 0, 0, 0, 7, 3], [-12, 0, 0, -4, -6, 0, 2, -8, 0, 10, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0], [-24, 0, 0, 0, -24, 0, 2, 5, 0, -1, 0, 0], [0, -4, -4, 0, 0, 0, 0, 0, -1, 0, 0, 1], [7, 0, 0, -4, -7, 0, -7, -2, 0, 2, 0, 0], [0, 0, 0, 4, 0, 0, 8, 4, 0, 0, 0, 0], [0, 0, -11, 0, 0, 6, 0, 0, -6, 0, -3, -3], [-6, 0, 0, 5, 0, 0, 0, 5, 0, -5, 0, 0], [0, 7, 0, 0, 0, 1, 0, 0, 0, 0, 1, -1], [0, -4, 2, 0, 0, 0, 0, 0, -4, 0, 6, -2], [14, 0, 0, -2, 7, 0, -2, -4, 0, 2, 0, 0], [-4, 0, 0, -5, -2, 0, -2, -10, 0, 8, 0, 0], [0, 9, 9, 0, 0, 11, 0, 0, 2, 0, 0, -2], [-5, 0, 0, 6, 0, 0, -4, 6, 0, -8, 0, 0], [0, 16, -8, 0, 0, 0, 0, 0, -4, 0, 6, -2], [10, 0, 0, -8, 0, 0, -4, -8, 0, 6, 0, 0], [10, 0, 0, 0, -10, 0, 2, 0, 0, 0, 0, 0], [0, 12, -12, 0, 0, 4, 0, 0, 4, 0, -8, -4], [0, -2, 1, 0, 0, 0, 0, 0, -3, 0, -3, -9], [22, 0, 0, 2, 11, 0, 1, 4, 0, -3, 0, 0], [0, -13, 26, 0, 0, -1, 0, 0, 4, 0, 1, 3], [0, 4, 4, 0, 0, 0, 0, 0, -4, 0, 0, 4], [2, 0, 0, 0, -2, 0, -8, 0, 0, 0, 0, 0], [0, 0, 0, -6, 19, 0, -3, 0, 0, 3, 0, 0], [0, 0, 0, -4, 12, 0, 4, 0, 0, -4, 0, 0], [-1, 0, 0, 8, 1, 0, 10, 4, 0, -4, 0, 0], [0, 6, 0, 0, 0, -2, 0, 0, 0, 0, -2, -2], [9, 0, 0, 0, 18, 0, 0, 0, 0, -1, 0, 0], [0, 0, 6, 0, 0, 4, 0, 0, -4, 0, -2, -2], [-3, 0, 0, -6, -6, 0, 0, 6, 0, 5, 0, 0], [0, -8, -8, 0, 0, 0, 0, 0, -3, 0, 0, 3], [0, 2, 2, 0, 0, -9, 0, 0, 0, 0, 0, 0], [6, 0, 0, 0, 0, 0, -8, 0, 0, -4, 0, 0], [0, 0, 0, 0, -7, 0, 2, 0, 0, -2, 0, 0], [0, 0, 0, 2, 0, 0, -4, 2, 0, -4, 0, 0], [0, 7, 0, 0, 0, 5, 0, 0, 0, 0, 5, -1], [0, -6, 6, 0, 0, 2, 0, 0, 0, 0, -4, -4], [0, -32, 16, 0, 0, 0, 0, 0, 2, 0, 0, 4], [0, 0, -23, 0, 0, 2, 0, 0, 3, 0, -1, -1], [0, -6, 12, 0, 0, 7, 0, 0, -4, 0, -7, -9], [0, 3, 3, 0, 0, -3, 0, 0, -2, 0, 0, 2], [0, -6, 12, 0, 0, -10, 0, 0, -4, 0, 10, 8], [0, 0, 0, 7, 12, 0, 6, 0, 0, -6, 0, 0], [12, 0, 0, 0, -12, 0, -2, 0, 0, 0, 0, 0], [0, 7, -7, 0, 0, 3, 0, 0, 10, 0, -6, 4], [6, 0, 0, -4, 3, 0, -11, -8, 0, -3, 0, 0], [0, -6, 12, 0, 0, 12, 0, 0, 0, 0, -12, -12], [12, 0, 0, 6, -12, 0, 0, 3, 0, -3, 0, 0], [0, 0, -24, 0, 0, -2, 0, 0, 0, 0, 1, 1], [0, 0, 0, -4, 18, 0, -8, 0, 0, 8, 0, 0], [0, 2, -1, 0, 0, 0, 0, 0, -2, 0, -7, -11], [-11, 0, 0, -4, 11, 0, -12, -2, 0, 2, 0, 0], [0, -6, 0, 0, 0, -1, 0, 0, 0, 0, -1, 5], [-4, 0, 0, -8, -2, 0, -12, -16, 0, 4, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0], [3, 0, 0, 2, 6, 0, 0, -2, 0, -6, 0, 0], [0, -5, -5, 0, 0, 7, 0, 0, -1, 0, 0, 1], [-4, 0, 0, 12, 4, 0, 12, 6, 0, -6, 0, 0], [-6, 0, 0, -4, 0, 0, -8, -4, 0, 0, 0, 0], [0, 0, -19, 0, 0, -2, 0, 0, -2, 0, 1, 1], [0, 10, 0, 0, 0, -6, 0, 0, 0, 0, -6, -9], [0, 0, 0, 0, 0, 0, -6, -12, 0, 0, 0, 0], [0, -1, 0, 0, 0, -5, 0, 0, 0, 0, -5, 1], [0, -4, 2, 0, 0, 0, 0, 0, 6, 0, -14, -2], [-8, 0, 0, 9, -4, 0, 12, 18, 0, -6, 0, 0], [0, -4, 8, 0, 0, -2, 0, 0, 8, 0, 2, 6], [-7, 0, 0, 0, -7, 0, -7, -8, 0, -6, 0, 0], [-13, 0, 0, 12, 0, 0, 12, 12, 0, -6, 0, 0], [0, 0, 0, -1, -6, 0, 4, 0, 0, -4, 0, 0], [0, 20, -10, 0, 0, 0, 0, 0, 8, 0, -11, 5], [0, -7, 7, 0, 0, 3, 0, 0, -6, 0, -6, -12], [-2, 0, 0, 7, -4, 0, 0, -7, 0, -11, 0, 0], [16, 0, 0, 0, 8, 0, 4, 0, 0, 4, 0, 0], [0, -2, -2, 0, 0, -10, 0, 0, 0, 0, 0, 0], [0, -7, 14, 0, 0, 3, 0, 0, 6, 0, -3, 0], [0, 0, 0, 8, 25, 0, 3, 0, 0, -3, 0, 0], [0, -2, 1, 0, 0, 0, 0, 0, 2, 0, 1, 5], [0, -6, 0, 0, 0, -6, 0, 0, 0, 0, -6, 6], [0, -19, 19, 0, 0, -5, 0, 0, -15, 0, 10, -5], [8, 0, 0, 2, 16, 0, 0, -2, 0, -10, 0, 0], [-24, 0, 0, 0, -12, 0, -6, 0, 0, -6, 0, 0], [5, 0, 0, 2, 10, 0, 0, -2, 0, -6, 0, 0], [6, 0, 0, 0, 6, 0, 8, 6, 0, 10, 0, 0], [0, 0, -4, 0, 0, 12, 0, 0, 12, 0, -6, -6], [18, 0, 0, -9, 0, 0, 0, -9, 0, 9, 0, 0], [-18, 0, 0, 0, -18, 0, 2, 12, 0, -8, 0, 0], [0, -16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [32, 0, 0, -5, 16, 0, -2, -10, 0, 8, 0, 0], [0, 0, -4, 0, 0, 12, 0, 0, -4, 0, -6, -6], [0, -4, 8, 0, 0, -5, 0, 0, 4, 0, 5, 7], [1, 0, 0, 0, 1, 0, -3, -12, 0, 6, 0, 0], [0, 4, -8, 0, 0, 12, 0, 0, 12, 0, -12, -6], [-7, 0, 0, 10, 0, 0, 2, 10, 0, -9, 0, 0], [4, 0, 0, -16, -4, 0, -10, -8, 0, 8, 0, 0], [0, -4, 4, 0, 0, 2, 0, 0, 4, 0, -4, 0], [0, 30, -30, 0, 0, 2, 0, 0, -8, 0, -4, -12], [-32, 0, 0, -4, -16, 0, 8, -8, 0, 16, 0, 0], [-8, 0, 0, 0, -16, 0, 0, 0, 0, -8, 0, 0], [0, 5, -10, 0, 0, 1, 0, 0, -12, 0, -1, -7], [0, 26, 26, 0, 0, -2, 0, 0, -2, 0, 0, 2], [0, 18, -9, 0, 0, 0, 0, 0, -2, 0, 1, -3], [0, 12, 0, 0, 0, -8, 0, 0, 0, 0, -8, 2], [0, -17, 17, 0, 0, 11, 0, 0, 10, 0, -22, -12], [-28, 0, 0, 0, -14, 0, -8, 0, 0, -8, 0, 0], [-11, 0, 0, -8, -22, 0, 0, 8, 0, 2, 0, 0], [-6, 0, 0, 0, -6, 0, -2, 9, 0, -13, 0, 0], [0, -2, -2, 0, 0, 16, 0, 0, 8, 0, 0, -8], [0, 0, 0, -4, 0, 0, -12, -4, 0, -2, 0, 0], [0, 23, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0], [0, 6, -6, 0, 0, -3, 0, 0, -8, 0, 6, -2], [-6, 0, 0, 0, -6, 0, -4, -12, 0, 4, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 8, 16], [0, 0, -19, 0, 0, 14, 0, 0, 19, 0, -7, -7], [7, 0, 0, 0, 7, 0, 3, 2, 0, 4, 0, 0], [-19, 0, 0, -8, 0, 0, -8, -8, 0, 4, 0, 0], [0, 0, 0, 15, -18, 0, -2, 0, 0, 2, 0, 0], [0, -4, 2, 0, 0, 0, 0, 0, 6, 0, 1, 13], [14, 0, 0, -6, 0, 0, -4, -6, 0, 4, 0, 0], [0, 36, -36, 0, 0, 4, 0, 0, 10, 0, -8, 2], [-17, 0, 0, 0, -17, 0, -6, -8, 0, -4, 0, 0], [0, 14, -7, 0, 0, 0, 0, 0, -9, 0, 17, -1], [-4, 0, 0, -8, -8, 0, 0, 8, 0, 4, 0, 0], [0, -9, 18, 0, 0, 1, 0, 0, -4, 0, -1, -3], [-16, 0, 0, -10, 16, 0, -10, -5, 0, 5, 0, 0], [0, -2, 4, 0, 0, 8, 0, 0, 12, 0, -8, -2], [0, 0, 0, -12, 31, 0, 1, 0, 0, -1, 0, 0], [0, -5, 5, 0, 0, -5, 0, 0, -7, 0, 10, 3], [0, 6, 0, 0, 0, 11, 0, 0, 0, 0, 11, -9], [3, 0, 0, -10, 6, 0, 0, 10, 0, 11, 0, 0], [-48, 0, 0, 0, -24, 0, 0, 0, 0, 0, 0, 0], [0, 0, -6, 0, 0, -20, 0, 0, -8, 0, 10, 10], [-6, 0, 0, 0, -6, 0, -2, 7, 0, -11, 0, 0], [12, 0, 0, -20, -12, 0, -12, -10, 0, 10, 0, 0], [0, 0, 19, 0, 0, -10, 0, 0, 10, 0, 5, 5], [0, 0, 0, 18, 5, 0, 12, 0, 0, -12, 0, 0], [0, -20, 10, 0, 0, 0, 0, 0, 6, 0, 10, 22], [-22, 0, 0, 8, -11, 0, 2, 16, 0, -14, 0, 0], [0, 24, -48, 0, 0, -5, 0, 0, 4, 0, 5, 7], [0, 14, 14, 0, 0, 20, 0, 0, 4, 0, 0, -4], [0, 0, 0, -22, 0, 0, -2, 0, 0, 2, 0, 0], [0, -28, 14, 0, 0, 0, 0, 0, -10, 0, 9, -11], [20, 0, 0, -8, -20, 0, 0, -4, 0, 4, 0, 0], [19, 0, 0, 0, 19, 0, -3, 6, 0, -12, 0, 0], [-24, 0, 0, 2, -12, 0, 4, 4, 0, 0, 0, 0], [-10, 0, 0, 4, -20, 0, 0, -4, 0, -4, 0, 0], [0, 20, 20, 0, 0, -4, 0, 0, -6, 0, 0, 6], [0, 0, 0, -18, 0, 0, -2, -9, 0, 9, 0, 0], [0, 17, -34, 0, 0, -1, 0, 0, 0, 0, 1, 1], [0, 0, 0, -12, -26, 0, -2, 0, 0, 2, 0, 0], [12, 0, 0, 8, -12, 0, 12, 4, 0, -4, 0, 0], [0, -18, 0, 0, 0, -2, 0, 0, 0, 0, -2, -2], [12, 0, 0, 0, 12, 0, -8, -19, 0, 3, 0, 0], [0, -2, -2, 0, 0, -8, 0, 0, -2, 0, 0, 2], [0, 0, 0, 0, 0, -3, 0, 0, -12, 0, 0, 12], [12, 0, 0, 20, 0, 0, 4, 20, 0, -18, 0, 0], [0, 0, 44, 0, 0, 0, 0, 0, -4, 0, 0, 0], [0, 0, 0, -18, -31, 0, -7, 0, 0, 7, 0, 0], [-18, 0, 0, -13, 0, 0, -24, -13, 0, 1, 0, 0], [0, -2, 0, 0, 0, 2, 0, 0, 0, 0, 2, 3], [0, 6, -6, 0, 0, -5, 0, 0, -10, 0, 10, 0], [0, -24, 12, 0, 0, 0, 0, 0, 6, 0, -8, 4], [6, 0, 0, -6, 3, 0, -3, -12, 0, 9, 0, 0], [0, 0, 2, 0, 0, -4, 0, 0, -21, 0, 2, 2], [12, 0, 0, 8, -12, 0, -2, 4, 0, -4, 0, 0], [0, 24, -24, 0, 0, -8, 0, 0, -12, 0, 16, 4], [-18, 0, 0, -4, -36, 0, 0, 4, 0, 4, 0, 0], [34, 0, 0, -6, 17, 0, -1, -12, 0, 11, 0, 0], [0, 5, -10, 0, 0, -21, 0, 0, -8, 0, 21, 17], [0, 0, 0, -4, 42, 0, -4, 0, 0, 4, 0, 0], [0, -2, 2, 0, 0, 2, 0, 0, 23, 0, -4, 19], [0, -24, 0, 0, 0, 7, 0, 0, 0, 0, 7, -17], [-8, 0, 0, -8, -16, 0, 0, 8, 0, -12, 0, 0], [-8, 0, 0, -8, -4, 0, 4, -16, 0, 20, 0, 0], [0, 0, 18, 0, 0, 28, 0, 0, 12, 0, -14, -14], [0, -5, -5, 0, 0, 13, 0, 0, -3, 0, 0, 3], [0, 18, 18, 0, 0, 0, 0, 0, 8, 0, 0, -8], [-5, 0, 0, 16, 5, 0, 1, 8, 0, -8, 0, 0], [0, 0, 28, 0, 0, 0, 0, 0, 4, 0, 0, 0], [0, -13, 0, 0, 0, 7, 0, 0, 0, 0, 7, 4], [-6, 0, 0, 0, -6, 0, 2, -8, 0, 12, 0, 0], [0, -11, 0, 0, 0, -3, 0, 0, 0, 0, -3, 15], [0, -12, 6, 0, 0, 0, 0, 0, -6, 0, -2, -14], [18, 0, 0, -8, 9, 0, -22, -16, 0, -6, 0, 0], [24, 0, 0, -3, 12, 0, 8, -6, 0, 14, 0, 0], [0, 0, 0, 0, 0, -6, 0, 0, -8, 0, 6, 2], [0, 22, -44, 0, 0, 2, 0, 0, 4, 0, -2, 0], [0, -4, 2, 0, 0, 0, 0, 0, 8, 0, 0, 16], [0, 11, -11, 0, 0, 5, 0, 0, -6, 0, -10, -16], [0, 2, -1, 0, 0, 0, 0, 0, -7, 0, 3, -11], [-56, 0, 0, -4, -28, 0, 0, -8, 0, 8, 0, 0], [8, 0, 0, 8, 16, 0, 0, -8, 0, 2, 0, 0], [0, 24, 24, 0, 0, 4, 0, 0, 4, 0, 0, -4], [0, 7, -14, 0, 0, 17, 0, 0, 18, 0, -17, -8], [0, 0, 30, 0, 0, 4, 0, 0, -4, 0, -2, -2], [0, -20, 10, 0, 0, 0, 0, 0, -4, 0, -10, -18], [0, 12, 0, 0, 0, -4, 0, 0, 0, 0, -4, -16], [-15, 0, 0, 6, -30, 0, 0, -6, 0, -15, 0, 0], [-48, 0, 0, 0, -24, 0, 6, 0, 0, 6, 0, 0], [0, 0, 6, 0, 0, 20, 0, 0, 12, 0, -10, -10], [15, 0, 0, -2, 30, 0, 0, 2, 0, -5, 0, 0], [30, 0, 0, 0, 30, 0, 8, 11, 0, 5, 0, 0], [0, -6, -6, 0, 0, -9, 0, 0, 2, 0, 0, -2], [-31, 0, 0, -8, 31, 0, -9, -4, 0, 4, 0, 0], [0, 0, 19, 0, 0, -10, 0, 0, -2, 0, 5, 5], [-12, 0, 0, -1, 0, 0, 16, -1, 0, 9, 0, 0], [-12, 0, 0, -10, -6, 0, -5, -20, 0, 15, 0, 0], [0, 0, 29, 0, 0, 6, 0, 0, 6, 0, -3, -3], [0, 6, -12, 0, 0, 5, 0, 0, 28, 0, -5, 9], [23, 0, 0, 0, 23, 0, -5, -6, 0, -4, 0, 0], [7, 0, 0, 10, 0, 0, 14, 10, 0, -3, 0, 0], [-10, 0, 0, 16, 10, 0, 8, 8, 0, -8, 0, 0], [0, 13, -13, 0, 0, 3, 0, 0, 2, 0, -6, -4], [-8, 0, 0, 3, -16, 0, 0, -3, 0, 7, 0, 0], [14, 0, 0, 0, 28, 0, 0, 0, 0, 0, 0, 0], [0, 10, -20, 0, 0, -2, 0, 0, 8, 0, 2, 6], [-32, 0, 0, -6, 32, 0, -4, -3, 0, 3, 0, 0], [0, 0, 0, -2, -7, 0, -5, 0, 0, 5, 0, 0], [0, -28, 14, 0, 0, 0, 0, 0, 4, 0, -14, -6], [7, 0, 0, -8, -7, 0, -10, -4, 0, 4, 0, 0], [0, -13, 13, 0, 0, -7, 0, 0, -3, 0, 14, 11], [-6, 0, 0, 6, -12, 0, 0, -6, 0, -7, 0, 0], [0, -22, -22, 0, 0, -12, 0, 0, -6, 0, 0, 6], [0, -28, -28, 0, 0, 5, 0, 0, -8, 0, 0, 8], [-1, 0, 0, 8, 1, 0, 17, 4, 0, -4, 0, 0], [0, 0, 0, -30, -5, 0, -13, 0, 0, 13, 0, 0], [0, 24, -24, 0, 0, 4, 0, 0, -8, 0, -8, -16], [0, -32, 16, 0, 0, 0, 0, 0, -6, 0, 8, -4], [0, 0, 25, 0, 0, -6, 0, 0, -9, 0, 3, 3], [0, 2, -4, 0, 0, -6, 0, 0, -20, 0, 6, -4], [-19, 0, 0, -6, 0, 0, 2, -6, 0, 7, 0, 0], [0, -20, 20, 0, 0, 0, 0, 0, 4, 0, 0, 4], [0, 18, -18, 0, 0, 2, 0, 0, 14, 0, -4, 10], [7, 0, 0, 0, 7, 0, -2, 6, 0, -10, 0, 0], [-8, 0, 0, 1, -16, 0, 0, -1, 0, 13, 0, 0], [0, -42, 21, 0, 0, 0, 0, 0, 1, 0, -3, -1], [2, 0, 0, -4, 4, 0, 0, 4, 0, 14, 0, 0], [-8, 0, 0, 8, 8, 0, 14, 4, 0, -4, 0, 0], [0, 0, 18, 0, 0, 2, 0, 0, 2, 0, -1, -1], [0, 0, 0, 8, -6, 0, 10, 0, 0, -10, 0, 0], [0, -48, 0, 0, 0, 0, 0, 0, 0, 0, 0, -8], [-13, 0, 0, 8, -26, 0, 0, -8, 0, 5, 0, 0], [24, 0, 0, 0, 24, 0, 4, 3, 0, 5, 0, 0], [0, -7, -7, 0, 0, -19, 0, 0, -12, 0, 0, 12], [0, 0, 0, 18, 0, 0, 20, 18, 0, -8, 0, 0], [0, -6, 6, 0, 0, 14, 0, 0, 8, 0, -28, -20], [0, 7, 0, 0, 0, -7, 0, 0, 0, 0, -7, -13], [-8, 0, 0, -4, -4, 0, 20, -8, 0, 28, 0, 0], [-64, 0, 0, 1, -32, 0, 6, 2, 0, 4, 0, 0], [0, 0, -38, 0, 0, -12, 0, 0, -15, 0, 6, 6]]
